Boost logo

Boost-Commit :

From: dgregor_at_[hidden]
Date: 2007-05-19 00:19:34


Author: dgregor
Date: 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
New Revision: 4126
URL: http://svn.boost.org/trac/boost/changeset/4126

Log:
Add testing support for Config library, fix testing support for dynamic bitset library

Added:
   sandbox/troy/boost_1_34_0/libs/config/test/CMakeLists.txt
   sandbox/troy/boost_1_34_0/libs/dynamic_bitset/test/
   sandbox/troy/boost_1_34_0/libs/dynamic_bitset/test/CMakeLists.txt
Text files modified:
   sandbox/troy/boost_1_34_0/libs/config/CMakeLists.txt | 4 +
   sandbox/troy/boost_1_34_0/libs/config/test/Jamfile.v2 | 39 ++++++-------
   sandbox/troy/boost_1_34_0/libs/config/test/config_info.cpp | 6 ++
   sandbox/troy/boost_1_34_0/libs/config/test/config_test.cpp | 114 ++++++++++++++++++++--------------------
   sandbox/troy/boost_1_34_0/libs/config/tools/generate.cpp | 35 ++++++++++-
   sandbox/troy/boost_1_34_0/libs/dynamic_bitset/CMakeLists.txt | 8 --
   6 files changed, 118 insertions(+), 88 deletions(-)

Modified: sandbox/troy/boost_1_34_0/libs/config/CMakeLists.txt
==============================================================================
--- sandbox/troy/boost_1_34_0/libs/config/CMakeLists.txt (original)
+++ sandbox/troy/boost_1_34_0/libs/config/CMakeLists.txt 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1 +1,3 @@
-MESSAGE(STATUS "*** Gore Warning: program that generates jamfile ***")
+boost_library_subproject(
+ Config
+ TESTDIRS test)

Added: sandbox/troy/boost_1_34_0/libs/config/test/CMakeLists.txt
==============================================================================
--- (empty file)
+++ sandbox/troy/boost_1_34_0/libs/config/test/CMakeLists.txt 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -0,0 +1,220 @@
+#
+# Regression test rules for Boost configuration setup.
+# *** DO NOT EDIT THIS FILE BY HAND ***
+# This file was automatically generated on Fri May 18 22:13:10 2007
+# by libs/config/tools/generate.cpp
+# Copyright John Maddock and Douglas Gregor.
+# Use, modification and distribution are subject to the
+# Boost Software License, Version 1.0. (See accompanying file
+# LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
+boost_test_run(config_info)
+boost_test_run(math_info)
+boost_test_run(config_test)
+boost_test_run(limits_test LIBRARIES boost_test_exec_monitor-static)
+boost_test_run(abi_test SOURCES abi/abi_test.cpp abi/main.cpp)
+
+boost_test_run(has_2arg_use_facet_pass)
+boost_test_compile_fail(has_2arg_use_facet_fail)
+boost_test_run(has_bethreads_pass)
+boost_test_compile_fail(has_bethreads_fail)
+boost_test_run(has_clock_gettime_pass)
+boost_test_compile_fail(has_clock_gettime_fail)
+boost_test_run(has_dirent_h_pass)
+boost_test_compile_fail(has_dirent_h_fail)
+boost_test_run(has_expm1_pass)
+boost_test_compile_fail(has_expm1_fail)
+boost_test_run(has_ftime_pass)
+boost_test_compile_fail(has_ftime_fail)
+boost_test_run(has_gettimeofday_pass)
+boost_test_compile_fail(has_gettimeofday_fail)
+boost_test_run(has_hash_pass)
+boost_test_compile_fail(has_hash_fail)
+boost_test_run(has_log1p_pass)
+boost_test_compile_fail(has_log1p_fail)
+boost_test_run(has_long_long_pass)
+boost_test_compile_fail(has_long_long_fail)
+boost_test_run(has_macro_use_facet_pass)
+boost_test_compile_fail(has_macro_use_facet_fail)
+boost_test_run(has_ms_int64_pass)
+boost_test_compile_fail(has_ms_int64_fail)
+boost_test_run(has_nanosleep_pass)
+boost_test_compile_fail(has_nanosleep_fail)
+boost_test_run(has_nl_types_h_pass)
+boost_test_compile_fail(has_nl_types_h_fail)
+boost_test_run(has_nrvo_pass)
+boost_test_compile_fail(has_nrvo_fail)
+boost_test_run(has_part_alloc_pass)
+boost_test_compile_fail(has_part_alloc_fail)
+boost_test_run(has_pthread_delay_np_pass)
+boost_test_compile_fail(has_pthread_delay_np_fail)
+boost_test_run(has_pthread_ma_st_pass)
+boost_test_compile_fail(has_pthread_ma_st_fail)
+boost_test_run(has_pthread_yield_pass)
+boost_test_compile_fail(has_pthread_yield_fail)
+boost_test_run(has_pthreads_pass)
+boost_test_compile_fail(has_pthreads_fail)
+boost_test_run(has_sched_yield_pass)
+boost_test_compile_fail(has_sched_yield_fail)
+boost_test_run(has_sgi_type_traits_pass)
+boost_test_compile_fail(has_sgi_type_traits_fail)
+boost_test_run(has_sigaction_pass)
+boost_test_compile_fail(has_sigaction_fail)
+boost_test_run(has_slist_pass)
+boost_test_compile_fail(has_slist_fail)
+boost_test_run(has_stdint_h_pass)
+boost_test_compile_fail(has_stdint_h_fail)
+boost_test_run(has_stlp_use_facet_pass)
+boost_test_compile_fail(has_stlp_use_facet_fail)
+boost_test_run(has_tr1_array_pass)
+boost_test_compile_fail(has_tr1_array_fail)
+boost_test_run(has_tr1_bind_pass)
+boost_test_compile_fail(has_tr1_bind_fail)
+boost_test_run(has_tr1_complex_over_pass)
+boost_test_compile_fail(has_tr1_complex_over_fail)
+boost_test_run(has_tr1_complex_trig_pass)
+boost_test_compile_fail(has_tr1_complex_trig_fail)
+boost_test_run(has_tr1_function_pass)
+boost_test_compile_fail(has_tr1_function_fail)
+boost_test_run(has_tr1_hash_pass)
+boost_test_compile_fail(has_tr1_hash_fail)
+boost_test_run(has_tr1_mem_fn_pass)
+boost_test_compile_fail(has_tr1_mem_fn_fail)
+boost_test_run(has_tr1_random_pass)
+boost_test_compile_fail(has_tr1_random_fail)
+boost_test_run(has_tr1_ref_wrap_pass)
+boost_test_compile_fail(has_tr1_ref_wrap_fail)
+boost_test_run(has_tr1_regex_pass)
+boost_test_compile_fail(has_tr1_regex_fail)
+boost_test_run(has_tr1_result_of_pass)
+boost_test_compile_fail(has_tr1_result_of_fail)
+boost_test_run(has_tr1_shared_ptr_pass)
+boost_test_compile_fail(has_tr1_shared_ptr_fail)
+boost_test_run(has_tr1_tuple_pass)
+boost_test_compile_fail(has_tr1_tuple_fail)
+boost_test_run(has_tr1_type_traits_pass)
+boost_test_compile_fail(has_tr1_type_traits_fail)
+boost_test_run(has_tr1_unordered_map_pass)
+boost_test_compile_fail(has_tr1_unordered_map_fail)
+boost_test_run(has_tr1_unordered_set_pass)
+boost_test_compile_fail(has_tr1_unordered_set_fail)
+boost_test_run(has_tr1_utility_pass)
+boost_test_compile_fail(has_tr1_utility_fail)
+boost_test_run(has_unistd_h_pass)
+boost_test_compile_fail(has_unistd_h_fail)
+boost_test_run(has_vc6_mem_templ_pass)
+boost_test_compile_fail(has_vc6_mem_templ_fail)
+boost_test_run(has_vc_iterator_pass)
+boost_test_compile_fail(has_vc_iterator_fail)
+boost_test_run(has_winthreads_pass)
+boost_test_compile_fail(has_winthreads_fail)
+boost_test_run(no_arg_dep_lookup_pass)
+boost_test_compile_fail(no_arg_dep_lookup_fail)
+boost_test_run(no_array_type_spec_pass)
+boost_test_compile_fail(no_array_type_spec_fail)
+boost_test_run(no_auto_ptr_pass)
+boost_test_compile_fail(no_auto_ptr_fail)
+boost_test_run(no_bcb_partial_spec_pass)
+boost_test_compile_fail(no_bcb_partial_spec_fail)
+boost_test_run(no_ctype_functions_pass)
+boost_test_compile_fail(no_ctype_functions_fail)
+boost_test_run(no_cv_spec_pass)
+boost_test_compile_fail(no_cv_spec_fail)
+boost_test_run(no_cv_void_spec_pass)
+boost_test_compile_fail(no_cv_void_spec_fail)
+boost_test_run(no_cwchar_pass)
+boost_test_compile_fail(no_cwchar_fail)
+boost_test_run(no_cwctype_pass)
+boost_test_compile_fail(no_cwctype_fail)
+boost_test_run(no_ded_typename_pass)
+boost_test_compile_fail(no_ded_typename_fail)
+boost_test_run(no_dep_nested_class_pass)
+boost_test_compile_fail(no_dep_nested_class_fail)
+boost_test_run(no_dep_val_param_pass)
+boost_test_compile_fail(no_dep_val_param_fail)
+boost_test_run(no_excep_std_pass)
+boost_test_compile_fail(no_excep_std_fail)
+boost_test_run(no_exceptions_pass)
+boost_test_compile_fail(no_exceptions_fail)
+boost_test_run(no_exp_func_tem_arg_pass)
+boost_test_compile_fail(no_exp_func_tem_arg_fail)
+boost_test_run(no_func_tmp_order_pass)
+boost_test_compile_fail(no_func_tmp_order_fail)
+boost_test_run(no_i64_limits_pass)
+boost_test_compile_fail(no_i64_limits_fail)
+boost_test_run(no_inline_memb_init_pass)
+boost_test_compile_fail(no_inline_memb_init_fail)
+boost_test_run(no_integral_int64_t_pass)
+boost_test_compile_fail(no_integral_int64_t_fail)
+boost_test_run(no_is_abstract_pass)
+boost_test_compile_fail(no_is_abstract_fail)
+boost_test_run(no_iter_construct_pass)
+boost_test_compile_fail(no_iter_construct_fail)
+boost_test_run(no_limits_pass)
+boost_test_compile_fail(no_limits_fail)
+boost_test_run(no_limits_const_exp_pass)
+boost_test_compile_fail(no_limits_const_exp_fail)
+boost_test_run(no_ll_limits_pass)
+boost_test_compile_fail(no_ll_limits_fail)
+boost_test_run(no_mem_func_spec_pass)
+boost_test_compile_fail(no_mem_func_spec_fail)
+boost_test_run(no_mem_tem_keyword_pass)
+boost_test_compile_fail(no_mem_tem_keyword_fail)
+boost_test_run(no_mem_tem_pnts_pass)
+boost_test_compile_fail(no_mem_tem_pnts_fail)
+boost_test_run(no_mem_templ_frnds_pass)
+boost_test_compile_fail(no_mem_templ_frnds_fail)
+boost_test_run(no_mem_templates_pass)
+boost_test_compile_fail(no_mem_templates_fail)
+boost_test_run(no_ops_in_namespace_pass)
+boost_test_compile_fail(no_ops_in_namespace_fail)
+boost_test_run(no_partial_spec_pass)
+boost_test_compile_fail(no_partial_spec_fail)
+boost_test_run(no_priv_aggregate_pass)
+boost_test_compile_fail(no_priv_aggregate_fail)
+boost_test_run(no_ptr_mem_const_pass)
+boost_test_compile_fail(no_ptr_mem_const_fail)
+boost_test_run(no_ret_det_pass)
+boost_test_compile_fail(no_ret_det_fail)
+boost_test_run(no_sfinae_pass)
+boost_test_compile_fail(no_sfinae_fail)
+boost_test_run(no_sstream_pass)
+boost_test_compile_fail(no_sstream_fail)
+boost_test_run(no_std_allocator_pass)
+boost_test_compile_fail(no_std_allocator_fail)
+boost_test_run(no_std_distance_pass)
+boost_test_compile_fail(no_std_distance_fail)
+boost_test_run(no_std_iter_traits_pass)
+boost_test_compile_fail(no_std_iter_traits_fail)
+boost_test_run(no_std_iterator_pass)
+boost_test_compile_fail(no_std_iterator_fail)
+boost_test_run(no_std_locale_pass)
+boost_test_compile_fail(no_std_locale_fail)
+boost_test_run(no_std_messages_pass)
+boost_test_compile_fail(no_std_messages_fail)
+boost_test_run(no_std_min_max_pass)
+boost_test_compile_fail(no_std_min_max_fail)
+boost_test_run(no_std_oi_assign_pass)
+boost_test_compile_fail(no_std_oi_assign_fail)
+boost_test_run(no_std_use_facet_pass)
+boost_test_compile_fail(no_std_use_facet_fail)
+boost_test_run(no_std_wstreambuf_pass)
+boost_test_compile_fail(no_std_wstreambuf_fail)
+boost_test_run(no_std_wstring_pass)
+boost_test_compile_fail(no_std_wstring_fail)
+boost_test_run(no_stdc_namespace_pass)
+boost_test_compile_fail(no_stdc_namespace_fail)
+boost_test_run(no_swprintf_pass)
+boost_test_compile_fail(no_swprintf_fail)
+boost_test_run(no_template_template_pass)
+boost_test_compile_fail(no_template_template_fail)
+boost_test_run(no_using_breaks_adl_pass)
+boost_test_compile_fail(no_using_breaks_adl_fail)
+boost_test_run(no_using_decl_overld_pass)
+boost_test_compile_fail(no_using_decl_overld_fail)
+boost_test_run(no_using_template_pass)
+boost_test_compile_fail(no_using_template_fail)
+boost_test_run(no_void_returns_pass)
+boost_test_compile_fail(no_void_returns_fail)
+boost_test_run(no_wchar_t_pass)
+boost_test_compile_fail(no_wchar_t_fail)
+

Modified: sandbox/troy/boost_1_34_0/libs/config/test/Jamfile.v2
==============================================================================
--- sandbox/troy/boost_1_34_0/libs/config/test/Jamfile.v2 (original)
+++ sandbox/troy/boost_1_34_0/libs/config/test/Jamfile.v2 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1,7 +1,7 @@
 #
 # Regression test Jamfile for boost configuration setup.
 # *** DO NOT EDIT THIS FILE BY HAND ***
-# This file was automatically generated on Wed Feb 15 14:14:07 2006
+# This file was automatically generated on Fri May 18 22:13:10 2007
 # by libs/config/tools/generate.cpp
 # Copyright John Maddock.
 # Use, modification and distribution are subject to the
@@ -68,9 +68,6 @@
 test-suite "BOOST_HAS_PARTIAL_STD_ALLOCATOR" :
 [ run has_part_alloc_pass.cpp ]
 [ compile-fail has_part_alloc_fail.cpp ] ;
-test-suite "BOOST_HAS_PTHREADS" :
-[ run has_pthreads_pass.cpp ]
-[ compile-fail has_pthreads_fail.cpp ] ;
 test-suite "BOOST_HAS_PTHREAD_DELAY_NP" :
 [ run has_pthread_delay_np_pass.cpp ]
 [ compile-fail has_pthread_delay_np_fail.cpp ] ;
@@ -80,6 +77,9 @@
 test-suite "BOOST_HAS_PTHREAD_YIELD" :
 [ run has_pthread_yield_pass.cpp ]
 [ compile-fail has_pthread_yield_fail.cpp ] ;
+test-suite "BOOST_HAS_PTHREADS" :
+[ run has_pthreads_pass.cpp ]
+[ compile-fail has_pthreads_fail.cpp ] ;
 test-suite "BOOST_HAS_SCHED_YIELD" :
 [ run has_sched_yield_pass.cpp ]
 [ compile-fail has_sched_yield_fail.cpp ] ;
@@ -197,12 +197,12 @@
 test-suite "BOOST_NO_DEPENDENT_TYPES_IN_TEMPLATE_VALUE_PARAMETERS" :
 [ run no_dep_val_param_pass.cpp ]
 [ compile-fail no_dep_val_param_fail.cpp ] ;
-test-suite "BOOST_NO_EXCEPTIONS" :
-[ run no_exceptions_pass.cpp ]
-[ compile-fail no_exceptions_fail.cpp ] ;
 test-suite "BOOST_NO_EXCEPTION_STD_NAMESPACE" :
 [ run no_excep_std_pass.cpp ]
 [ compile-fail no_excep_std_fail.cpp ] ;
+test-suite "BOOST_NO_EXCEPTIONS" :
+[ run no_exceptions_pass.cpp ]
+[ compile-fail no_exceptions_fail.cpp ] ;
 test-suite "BOOST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS" :
 [ run no_exp_func_tem_arg_pass.cpp ]
 [ compile-fail no_exp_func_tem_arg_fail.cpp ] ;
@@ -236,18 +236,18 @@
 test-suite "BOOST_NO_MEMBER_FUNCTION_SPECIALIZATIONS" :
 [ run no_mem_func_spec_pass.cpp ]
 [ compile-fail no_mem_func_spec_fail.cpp ] ;
-test-suite "BOOST_NO_MEMBER_TEMPLATES" :
-[ run no_mem_templates_pass.cpp ]
-[ compile-fail no_mem_templates_fail.cpp ] ;
-test-suite "BOOST_NO_MEMBER_TEMPLATE_FRIENDS" :
-[ run no_mem_templ_frnds_pass.cpp ]
-[ compile-fail no_mem_templ_frnds_fail.cpp ] ;
 test-suite "BOOST_NO_MEMBER_TEMPLATE_KEYWORD" :
 [ run no_mem_tem_keyword_pass.cpp ]
 [ compile-fail no_mem_tem_keyword_fail.cpp ] ;
 test-suite "BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS" :
 [ run no_mem_tem_pnts_pass.cpp ]
 [ compile-fail no_mem_tem_pnts_fail.cpp ] ;
+test-suite "BOOST_NO_MEMBER_TEMPLATE_FRIENDS" :
+[ run no_mem_templ_frnds_pass.cpp ]
+[ compile-fail no_mem_templ_frnds_fail.cpp ] ;
+test-suite "BOOST_NO_MEMBER_TEMPLATES" :
+[ run no_mem_templates_pass.cpp ]
+[ compile-fail no_mem_templates_fail.cpp ] ;
 test-suite "BOOST_NO_OPERATORS_IN_NAMESPACE" :
 [ run no_ops_in_namespace_pass.cpp ]
 [ compile-fail no_ops_in_namespace_fail.cpp ] ;
@@ -269,21 +269,18 @@
 test-suite "BOOST_NO_STRINGSTREAM" :
 [ run no_sstream_pass.cpp ]
 [ compile-fail no_sstream_fail.cpp ] ;
-test-suite "BOOST_NO_STDC_NAMESPACE" :
-[ run no_stdc_namespace_pass.cpp ]
-[ compile-fail no_stdc_namespace_fail.cpp ] ;
 test-suite "BOOST_NO_STD_ALLOCATOR" :
 [ run no_std_allocator_pass.cpp ]
 [ compile-fail no_std_allocator_fail.cpp ] ;
 test-suite "BOOST_NO_STD_DISTANCE" :
 [ run no_std_distance_pass.cpp ]
 [ compile-fail no_std_distance_fail.cpp ] ;
-test-suite "BOOST_NO_STD_ITERATOR" :
-[ run no_std_iterator_pass.cpp ]
-[ compile-fail no_std_iterator_fail.cpp ] ;
 test-suite "BOOST_NO_STD_ITERATOR_TRAITS" :
 [ run no_std_iter_traits_pass.cpp ]
 [ compile-fail no_std_iter_traits_fail.cpp ] ;
+test-suite "BOOST_NO_STD_ITERATOR" :
+[ run no_std_iterator_pass.cpp ]
+[ compile-fail no_std_iterator_fail.cpp ] ;
 test-suite "BOOST_NO_STD_LOCALE" :
 [ run no_std_locale_pass.cpp ]
 [ compile-fail no_std_locale_fail.cpp ] ;
@@ -305,6 +302,9 @@
 test-suite "BOOST_NO_STD_WSTRING" :
 [ run no_std_wstring_pass.cpp ]
 [ compile-fail no_std_wstring_fail.cpp ] ;
+test-suite "BOOST_NO_STDC_NAMESPACE" :
+[ run no_stdc_namespace_pass.cpp ]
+[ compile-fail no_stdc_namespace_fail.cpp ] ;
 test-suite "BOOST_NO_SWPRINTF" :
 [ run no_swprintf_pass.cpp ]
 [ compile-fail no_swprintf_fail.cpp ] ;
@@ -327,4 +327,3 @@
 [ run no_wchar_t_pass.cpp ]
 [ compile-fail no_wchar_t_fail.cpp ] ;
 
-

Modified: sandbox/troy/boost_1_34_0/libs/config/test/config_info.cpp
==============================================================================
--- sandbox/troy/boost_1_34_0/libs/config/test/config_info.cpp (original)
+++ sandbox/troy/boost_1_34_0/libs/config/test/config_info.cpp 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1000,6 +1000,12 @@
 
 
 
+
+
+
+
+
+
    // END GENERATED BLOCK
 
    PRINT_MACRO(BOOST_INTEL);

Modified: sandbox/troy/boost_1_34_0/libs/config/test/config_test.cpp
==============================================================================
--- sandbox/troy/boost_1_34_0/libs/config/test/config_test.cpp (original)
+++ sandbox/troy/boost_1_34_0/libs/config/test/config_test.cpp 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1,4 +1,4 @@
-// This file was automatically generated on Wed Feb 15 14:14:06 2006
+// This file was automatically generated on Fri May 18 22:13:10 2007
 // by libs/config/tools/generate.cpp
 // Copyright John Maddock 2002-4.
 // Use, modification and distribution are subject to the
@@ -79,16 +79,16 @@
 #else
 namespace boost_no_dependent_types_in_template_value_parameters = empty_boost;
 #endif
-#ifndef BOOST_NO_EXCEPTIONS
-#include "boost_no_exceptions.ipp"
-#else
-namespace boost_no_exceptions = empty_boost;
-#endif
 #ifndef BOOST_NO_EXCEPTION_STD_NAMESPACE
 #include "boost_no_excep_std.ipp"
 #else
 namespace boost_no_exception_std_namespace = empty_boost;
 #endif
+#ifndef BOOST_NO_EXCEPTIONS
+#include "boost_no_exceptions.ipp"
+#else
+namespace boost_no_exceptions = empty_boost;
+#endif
 #ifndef BOOST_NO_EXPLICIT_FUNCTION_TEMPLATE_ARGUMENTS
 #include "boost_no_exp_func_tem_arg.ipp"
 #else
@@ -144,16 +144,6 @@
 #else
 namespace boost_no_member_function_specializations = empty_boost;
 #endif
-#ifndef BOOST_NO_MEMBER_TEMPLATES
-#include "boost_no_mem_templates.ipp"
-#else
-namespace boost_no_member_templates = empty_boost;
-#endif
-#ifndef BOOST_NO_MEMBER_TEMPLATE_FRIENDS
-#include "boost_no_mem_templ_frnds.ipp"
-#else
-namespace boost_no_member_template_friends = empty_boost;
-#endif
 #ifndef BOOST_NO_MEMBER_TEMPLATE_KEYWORD
 #include "boost_no_mem_tem_keyword.ipp"
 #else
@@ -164,6 +154,16 @@
 #else
 namespace boost_no_pointer_to_member_template_parameters = empty_boost;
 #endif
+#ifndef BOOST_NO_MEMBER_TEMPLATE_FRIENDS
+#include "boost_no_mem_templ_frnds.ipp"
+#else
+namespace boost_no_member_template_friends = empty_boost;
+#endif
+#ifndef BOOST_NO_MEMBER_TEMPLATES
+#include "boost_no_mem_templates.ipp"
+#else
+namespace boost_no_member_templates = empty_boost;
+#endif
 #ifndef BOOST_NO_OPERATORS_IN_NAMESPACE
 #include "boost_no_ops_in_namespace.ipp"
 #else
@@ -199,11 +199,6 @@
 #else
 namespace boost_no_stringstream = empty_boost;
 #endif
-#ifndef BOOST_NO_STDC_NAMESPACE
-#include "boost_no_stdc_namespace.ipp"
-#else
-namespace boost_no_stdc_namespace = empty_boost;
-#endif
 #ifndef BOOST_NO_STD_ALLOCATOR
 #include "boost_no_std_allocator.ipp"
 #else
@@ -214,16 +209,16 @@
 #else
 namespace boost_no_std_distance = empty_boost;
 #endif
-#ifndef BOOST_NO_STD_ITERATOR
-#include "boost_no_std_iterator.ipp"
-#else
-namespace boost_no_std_iterator = empty_boost;
-#endif
 #ifndef BOOST_NO_STD_ITERATOR_TRAITS
 #include "boost_no_std_iter_traits.ipp"
 #else
 namespace boost_no_std_iterator_traits = empty_boost;
 #endif
+#ifndef BOOST_NO_STD_ITERATOR
+#include "boost_no_std_iterator.ipp"
+#else
+namespace boost_no_std_iterator = empty_boost;
+#endif
 #ifndef BOOST_NO_STD_LOCALE
 #include "boost_no_std_locale.ipp"
 #else
@@ -259,6 +254,11 @@
 #else
 namespace boost_no_std_wstring = empty_boost;
 #endif
+#ifndef BOOST_NO_STDC_NAMESPACE
+#include "boost_no_stdc_namespace.ipp"
+#else
+namespace boost_no_stdc_namespace = empty_boost;
+#endif
 #ifndef BOOST_NO_SWPRINTF
 #include "boost_no_swprintf.ipp"
 #else
@@ -375,11 +375,6 @@
 #else
 namespace boost_has_partial_std_allocator = empty_boost;
 #endif
-#ifdef BOOST_HAS_PTHREADS
-#include "boost_has_pthreads.ipp"
-#else
-namespace boost_has_pthreads = empty_boost;
-#endif
 #ifdef BOOST_HAS_PTHREAD_DELAY_NP
 #include "boost_has_pthread_delay_np.ipp"
 #else
@@ -395,6 +390,11 @@
 #else
 namespace boost_has_pthread_yield = empty_boost;
 #endif
+#ifdef BOOST_HAS_PTHREADS
+#include "boost_has_pthreads.ipp"
+#else
+namespace boost_has_pthreads = empty_boost;
+#endif
 #ifdef BOOST_HAS_SCHED_YIELD
 #include "boost_has_sched_yield.ipp"
 #else
@@ -613,11 +613,6 @@
       std::cerr << "Failed test for BOOST_HAS_PARTIAL_STD_ALLOCATOR at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_has_pthreads::test())
- {
- std::cerr << "Failed test for BOOST_HAS_PTHREADS at: " << __FILE__ << ":" << __LINE__ << std::endl;
- ++error_count;
- }
    if(0 != boost_has_pthread_delay_np::test())
    {
       std::cerr << "Failed test for BOOST_HAS_PTHREAD_DELAY_NP at: " << __FILE__ << ":" << __LINE__ << std::endl;
@@ -633,6 +628,11 @@
       std::cerr << "Failed test for BOOST_HAS_PTHREAD_YIELD at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
+ if(0 != boost_has_pthreads::test())
+ {
+ std::cerr << "Failed test for BOOST_HAS_PTHREADS at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ ++error_count;
+ }
    if(0 != boost_has_sched_yield::test())
    {
       std::cerr << "Failed test for BOOST_HAS_SCHED_YIELD at: " << __FILE__ << ":" << __LINE__ << std::endl;
@@ -828,14 +828,14 @@
       std::cerr << "Failed test for BOOST_NO_DEPENDENT_TYPES_IN_TEMPLATE_VALUE_PARAMETERS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_exceptions::test())
+ if(0 != boost_no_exception_std_namespace::test())
    {
- std::cerr << "Failed test for BOOST_NO_EXCEPTIONS at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_EXCEPTION_STD_NAMESPACE at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_exception_std_namespace::test())
+ if(0 != boost_no_exceptions::test())
    {
- std::cerr << "Failed test for BOOST_NO_EXCEPTION_STD_NAMESPACE at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_EXCEPTIONS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
    if(0 != boost_no_explicit_function_template_arguments::test())
@@ -893,24 +893,24 @@
       std::cerr << "Failed test for BOOST_NO_MEMBER_FUNCTION_SPECIALIZATIONS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_member_templates::test())
+ if(0 != boost_no_member_template_keyword::test())
    {
- std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATES at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATE_KEYWORD at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_member_template_friends::test())
+ if(0 != boost_no_pointer_to_member_template_parameters::test())
    {
- std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATE_FRIENDS at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_member_template_keyword::test())
+ if(0 != boost_no_member_template_friends::test())
    {
- std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATE_KEYWORD at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATE_FRIENDS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_pointer_to_member_template_parameters::test())
+ if(0 != boost_no_member_templates::test())
    {
- std::cerr << "Failed test for BOOST_NO_POINTER_TO_MEMBER_TEMPLATE_PARAMETERS at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_MEMBER_TEMPLATES at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
    if(0 != boost_no_operators_in_namespace::test())
@@ -948,11 +948,6 @@
       std::cerr << "Failed test for BOOST_NO_STRINGSTREAM at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_stdc_namespace::test())
- {
- std::cerr << "Failed test for BOOST_NO_STDC_NAMESPACE at: " << __FILE__ << ":" << __LINE__ << std::endl;
- ++error_count;
- }
    if(0 != boost_no_std_allocator::test())
    {
       std::cerr << "Failed test for BOOST_NO_STD_ALLOCATOR at: " << __FILE__ << ":" << __LINE__ << std::endl;
@@ -963,14 +958,14 @@
       std::cerr << "Failed test for BOOST_NO_STD_DISTANCE at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_std_iterator::test())
+ if(0 != boost_no_std_iterator_traits::test())
    {
- std::cerr << "Failed test for BOOST_NO_STD_ITERATOR at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_STD_ITERATOR_TRAITS at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
- if(0 != boost_no_std_iterator_traits::test())
+ if(0 != boost_no_std_iterator::test())
    {
- std::cerr << "Failed test for BOOST_NO_STD_ITERATOR_TRAITS at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ std::cerr << "Failed test for BOOST_NO_STD_ITERATOR at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
    if(0 != boost_no_std_locale::test())
@@ -1008,6 +1003,11 @@
       std::cerr << "Failed test for BOOST_NO_STD_WSTRING at: " << __FILE__ << ":" << __LINE__ << std::endl;
       ++error_count;
    }
+ if(0 != boost_no_stdc_namespace::test())
+ {
+ std::cerr << "Failed test for BOOST_NO_STDC_NAMESPACE at: " << __FILE__ << ":" << __LINE__ << std::endl;
+ ++error_count;
+ }
    if(0 != boost_no_swprintf::test())
    {
       std::cerr << "Failed test for BOOST_NO_SWPRINTF at: " << __FILE__ << ":" << __LINE__ << std::endl;

Modified: sandbox/troy/boost_1_34_0/libs/config/tools/generate.cpp
==============================================================================
--- sandbox/troy/boost_1_34_0/libs/dynamic_bitset/CMakeLists.txt (original)
+++ sandbox/troy/boost_1_34_0/libs/dynamic_bitset/CMakeLists.txt 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1,8 +1,4 @@
 boost_library_subproject(
   Dynamic_bitset
-)
-
-boost_test_run(dyn_bitset_unit_tests1)
-boost_test_run(dyn_bitset_unit_tests2)
-boost_test_run(dyn_bitset_unit_tests3)
-boost_test_run(dyn_bitset_unit_tests4)
+ TESTDIRS test
+)
\ No newline at end of file

Added: sandbox/troy/boost_1_34_0/libs/dynamic_bitset/test/CMakeLists.txt
==============================================================================
--- (empty file)
+++ sandbox/troy/boost_1_34_0/libs/dynamic_bitset/test/CMakeLists.txt 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -0,0 +1,4 @@
+boost_test_run(dyn_bitset_unit_tests1)
+boost_test_run(dyn_bitset_unit_tests2)
+boost_test_run(dyn_bitset_unit_tests3)
+boost_test_run(dyn_bitset_unit_tests4)


Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
--- sandbox/troy/boost_1_34_0/libs/config/tools/generate.cpp (original)
+++ sandbox/troy/boost_1_34_0/libs/config/tools/generate.cpp 2007-05-19 00:19:33 EDT (Sat, 19 May 2007)
@@ -1,12 +1,13 @@
 // (C) Copyright John Maddock 2004.
+// (C) Douglas Gregor <doug.gregor_at_[hidden]> 2007.
 // Use, modification and distribution are subject to the
 // Boost Software License, Version 1.0. (See accompanying file
 // LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
 //
// This progam scans for *.ipp files in the libs/config/test
// directory and then generates the *.cpp test files from them
// along with config_test.cpp and a Jamfile.
 //
 
 #include <boost/regex.hpp>
@@ -37,6 +38,7 @@
 std::stringstream config_test2;
 std::stringstream jamfile;
 std::stringstream jamfile_v2;
+std::stringstream cmakelists;
 std::set<std::string> macro_list;
 
 
@@ -136,6 +138,25 @@
 
 }
 
+void write_cmakelists()
+{
+ fs::ofstream ofs(config_path / "CMakeLists.txt");
+ time_t t = std::time(0);
+ ofs << "#\n# Regression test rules for Boost configuration setup.\n# *** DO NOT EDIT THIS FILE BY HAND ***\n"
+ "# This file was automatically generated on " << std::ctime(&t);
+ ofs << "# by libs/config/tools/generate.cpp\n"
+ "# Copyright John Maddock and Douglas Gregor.\n"
+ "# Use, modification and distribution are subject to the \n"
+ "# Boost Software License, Version 1.0. (See accompanying file \n"
+ "# LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)\n"
+ "boost_test_run(config_info)\n"
+ "boost_test_run(math_info)\n"
+ "boost_test_run(config_test)\n"
+ "boost_test_run(limits_test LIBRARIES boost_test_exec_monitor-static)\n"
+ "boost_test_run(abi_test SOURCES abi/abi_test.cpp abi/main.cpp)\n\n";
+ ofs << cmakelists.str() << std::endl;
+}
+
 void write_test_file(const fs::path& file,
                      const std::string& macro_name,
                      const std::string& namespace_name,
@@ -256,7 +277,7 @@
       " ++error_count;\n"
       " }\n";
 
// always generate the jamfile data:
    jamfile << "test-suite \"" << macro_name << "\" : \n"
       "[ run " << positive_file.leaf() << " <template>config_options ]\n"
       "[ compile-fail " << negative_file.leaf() << " <template>config_options ] ;\n";
@@ -265,6 +286,11 @@
       "[ run " << positive_file.leaf() << " ]\n"
       "[ compile-fail " << negative_file.leaf() << " ] ;\n";
 
+ cmakelists << "boost_test_run("
+ << boost::regex_replace(file.leaf(), file_regex, "$1_pass")
+ << ")\nboost_test_compile_fail("
+ << boost::regex_replace(file.leaf(), file_regex, "$1_fail")
+ << ")\n";
 }
 
 int cpp_main(int argc, char* argv[])
@@ -300,6 +326,7 @@
    write_config_test();
    write_jamfile();
    write_jamfile_v2();
+ write_cmakelists();
    write_config_info();
    return 0;
 }
@@ -1,12 +1,13 @@
 
 //
-// This progam scans for *.ipp files in the libs/config/test
-// directory and then generates the *.cpp test files from them
-// along with config_test.cpp and a Jamfile.
+// This progam scans for *.ipp files in the libs/config/test directory
+// and then generates the *.cpp test files from them along with
+// config_test.cpp and either a Jamfile or a CMakeLists.txt file.
 //
 
@@ -256,7 +277,7 @@
       " }\n";
 
- // always generate the jamfile data:
+ // always generate the jamfile and CMake data:
    jamfile << "test-suite \"" << macro_name << "\" : \n"
       "[ run " << positive_file.leaf() << " <template>config_options ]\n"

Modified: sandbox/troy/boost_1_34_0/libs/dynamic_bitset/CMakeLists.txt
==============================================================================